@@ -1,7 +1,7 @@
 package App::FatPackUtils;
 
-our $DATE = '2015-06-17'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-07-03'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 
@@ -20,7 +20,7 @@ App::FatPackUtils - Collection of CLI utilities related to App::FatPacker
 
 =head1 VERSION
 
-This document describes version 0.02 of App::FatPackUtils (from Perl distribution App-FatPackUtils), released on 2015-06-17.
+This document describes version 0.03 of App::FatPackUtils (from Perl distribution App-FatPackUtils), released on 2015-07-03.
 
 =head1 DESCRIPTION
 
@@ -37,7 +37,9 @@ L<App::FatPacker>:
 
 =head1 SEE ALSO
 
-L<App::FatPacker>, L<App::fatten>
+L<App::FatPacker>, L<Module::FatPack>
+
+L<App::depak>
 
 =head1 HOMEPAGE
 
